marktools.detach_annotations_attached_to_component
==================================================

.. autofunction:: abjad.tools.marktools.detach_annotations_attached_to_component.detach_annotations_attached_to_component
